---
test_data: TD_76_09_29_31
test_title: overlapped `prop_value`-s from diff `prop_name`-s
---

Case: two different `prop_name`-s with some of their `prop_value`-s matching as strings.

For example, in `ServicePropName` `prop_name`-s, imagine `amer.us` `prop_value` is both:
*   `geo_region`
*   `host_name`

If such `prop_name`-s used in a query for an object, it is important:
*   to consume `command_arg`-s according to FS_76_29_13_28 `command_arg` consumption priority
    (in the order of `prop_name`-s in FS_31_70_49_15 `search_control`)
*   not to consume the same `command_arg` by more than one `prop_name`
